@@ -152,7 +152,7 @@ class MediaShowListingView(BrowserView):
         plone_utils = getToolByName(self.context, 'plone_utils')
         path = '/'.join(item.getPhysicalPath())
         
-        if item.portal_type == "Folder" or (item.restrictedTraverse('@@plone').isStructuralFolder()  and item.portal_type != "Topic" and item.portal_type != "Category Navigator"):
+        if item.portal_type == "Folder" or (item.restrictedTraverse('@@plone').isStructuralFolder()  and (item.portal_type != "Topic" and item.portal_type != "Collection") and item.portal_type != "Category Navigator"):
             if not recursiveMode:
                 results = catalog.searchResults(path = { 'query' : path, 'depth' : 1 }, sort_on = 'getObjPositionInParent')
             else:
@@ -162,6 +162,9 @@ class MediaShowListingView(BrowserView):
                 results = catalog.searchResults(item.buildQuery())[:item.itemCount]
             else:
                 results = catalog.searchResults(item.buildQuery())
+        elif item.portal_type == "Collection":
+            results = item.queryCatalog()
+                
         #TODO: This next part was made for porseleinplaats website to work with the category navigator and Object type
         #it is a hack and should be revised. the whole query string should be parsed into the search.
         #also found a problem where User objects get a wrong Image media url.
